diff --git a/ant-bridge.sh b/ant-bridge.sh
index 9f4713d7c..fe0549fa1 100755
--- a/ant-bridge.sh
+++ b/ant-bridge.sh
@@ -103,14 +103,14 @@ for arg in "${@}" ; do
mvn_args="${mvn_args} -Dsting.packagetests.enabled=true"
mvn_args="${mvn_args} -Dsting.packagecommittests.skipped=false"
- # TODO: This runs only the pipeline tests (full, non-dry run), but not the commit tests for Queue.
+ # TODO: This runs only the queue tests (full, non-dry run), but not the commit tests for Queue.
elif [[ "${arg}" == "queuefull.binary.release.tests" ]] ; then
local_repo="sitetemprepo"
mvn_args="install -Dmaven.repo.local=${local_repo} && mvn verify"
mvn_args="${mvn_args} -Dmaven.repo.local=${local_repo}"
mvn_args="${mvn_args} -Dsting.packagetests.enabled=true"
- mvn_args="${mvn_args} -Dsting.packagepipelinetests.skipped=false"
- mvn_args="${mvn_args} -Dsting.pipelinetests.run=true"
+ mvn_args="${mvn_args} -Dsting.packagequeuetests.skipped=false"
+ mvn_args="${mvn_args} -Dsting.queuetests.run=true"
elif [[ "${arg}" == "committests" ]] ; then
mvn_args="verify -Dsting.committests.skipped=false"
@@ -130,11 +130,11 @@ for arg in "${@}" ; do
elif [[ "${arg}" == "knowledgebasetest" ]] ; then
mvn_args="verify -Dsting.knowledgebasetests.skipped=false"
- elif [[ "${arg}" == "pipelinetest" ]] ; then
- mvn_args="verify -Dsting.pipelinetests.skipped=false"
+ elif [[ "${arg}" == "queuetest" ]] ; then
+ mvn_args="verify -Dsting.queuetests.skipped=false"
- elif [[ "${arg}" == "pipelinetestrun" ]] ; then
- mvn_args="verify -Dsting.pipelinetests.skipped=false -Dsting.pipelinetests.run=true"
+ elif [[ "${arg}" == "queuetestrun" ]] ; then
+ mvn_args="verify -Dsting.queuetests.skipped=false -Dsting.queuetests.run=true"
elif [[ "${arg}" == "fasttest" ]] ; then
mvn_args="verify -Dsting.committests.skipped=false -pl private/gatk-private -am -Dresource.bundle.skip=true"
diff --git a/pom.xml b/pom.xml
index e713df56f..eb3ace24f 100644
--- a/pom.xml
+++ b/pom.xml
@@ -48,7 +48,7 @@
true
${sting.packagecommittests.skipped}
${sting.packagecommittests.skipped}
- ${sting.packagecommittests.skipped}
+ ${sting.packagecommittests.skipped}
true
true
@@ -62,7 +62,7 @@
true
${sting.serialcommittests.skipped}
${sting.serialcommittests.skipped}
- ${sting.serialcommittests.skipped}
+ ${sting.serialcommittests.skipped}
true
true
@@ -561,7 +561,7 @@
${sting.packagetests.artifactId}
${project.build.testOutputDirectory}
${project.basedir}
- ${sting.pipelinetests.run}
+ ${sting.queuetests.run}
${maven.surefire.debug}
${maven.failsafe.debug}
@@ -613,7 +613,7 @@
- package-pipelinetests
+ package-queuetests
integration-test
verify
@@ -622,11 +622,11 @@
verify
- ${project.build.directory}/invoker-reports/pipeline/${it.test}
- ${sting.packagepipelinetests.skipped}
+ ${project.build.directory}/invoker-reports/queuetest/${it.test}
+ ${sting.packagequeuetests.skipped}
true
- ${sting.packagepipelinetests.skipped}
+ ${sting.packagequeuetests.skipped}
diff --git a/protected/gatk-protected/pom.xml b/protected/gatk-protected/pom.xml
index 509f984a3..3d60c1d61 100644
--- a/protected/gatk-protected/pom.xml
+++ b/protected/gatk-protected/pom.xml
@@ -99,7 +99,7 @@
package-knowledgebasetests
- package-pipelinetests
+ package-queuetests
diff --git a/public/gatk-framework/pom.xml b/public/gatk-framework/pom.xml
index 068c062a7..de7b1748e 100644
--- a/public/gatk-framework/pom.xml
+++ b/public/gatk-framework/pom.xml
@@ -86,7 +86,7 @@
package-knowledgebasetests
- package-pipelinetests
+ package-queuetests
diff --git a/public/gatk-framework/src/test/java/org/broadinstitute/sting/BaseTest.java b/public/gatk-framework/src/test/java/org/broadinstitute/sting/BaseTest.java
index e8aed7d50..809a6f1a1 100644
--- a/public/gatk-framework/src/test/java/org/broadinstitute/sting/BaseTest.java
+++ b/public/gatk-framework/src/test/java/org/broadinstitute/sting/BaseTest.java
@@ -135,7 +135,7 @@ public abstract class BaseTest {
public final static String NA12878_PCRFREE = privateTestDir + "PCRFree.2x250.Illumina.20_10_11.bam";
public final static String NA12878_WEx = privateTestDir + "CEUTrio.HiSeq.WEx.b37_decoy.NA12878.20_10_11mb.bam";
- public static final boolean pipelineTestRunModeIsSet = System.getProperty("pipeline.run", "").equals("run");
+ public static final boolean queueTestRunModeIsSet = System.getProperty("queuetest.run", "").equals("true");
/** before the class starts up */
static {
diff --git a/public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/drmaa/v1_0/JnaSessionPipelineTest.java b/public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/drmaa/v1_0/JnaSessionQueueTest.java
similarity index 95%
rename from public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/drmaa/v1_0/JnaSessionPipelineTest.java
rename to public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/drmaa/v1_0/JnaSessionQueueTest.java
index 5a6a1b769..1562ab93e 100644
--- a/public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/drmaa/v1_0/JnaSessionPipelineTest.java
+++ b/public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/drmaa/v1_0/JnaSessionQueueTest.java
@@ -35,7 +35,7 @@ import org.testng.annotations.Test;
import java.io.File;
import java.util.*;
-public class JnaSessionPipelineTest extends BaseTest {
+public class JnaSessionQueueTest extends BaseTest {
private String implementation = null;
private static final SessionFactory factory = new JnaSessionFactory();
@@ -52,15 +52,15 @@ public class JnaSessionPipelineTest extends BaseTest {
@Test(dependsOnMethods = { "testDrmaa" })
public void testSubmitEcho() throws Exception {
- if ( ! pipelineTestRunModeIsSet ) {
- throw new SkipException("Skipping testSubmitEcho because we are in pipeline test dry run mode");
+ if ( ! queueTestRunModeIsSet ) {
+ throw new SkipException("Skipping testSubmitEcho because we are in queue test dry run mode");
}
if (implementation.contains("LSF")) {
System.err.println(" ***********************************************************");
System.err.println(" *************************************************************");
System.err.println(" **** ****");
- System.err.println(" **** Skipping JnaSessionPipelineTest.testSubmitEcho() ****");
+ System.err.println(" **** Skipping JnaSessionQueueTest.testSubmitEcho() ****");
System.err.println(" **** Are you using the dotkit .combined_LSF_SGE? ****");
System.err.println(" **** ****");
System.err.println(" *************************************************************");
@@ -68,7 +68,7 @@ public class JnaSessionPipelineTest extends BaseTest {
throw new SkipException("Skipping testSubmitEcho because correct DRMAA implementation not found");
}
- File outFile = tryCreateNetworkTempFile("JnaSessionPipelineTest.out");
+ File outFile = tryCreateNetworkTempFile("JnaSessionQueueTest.out");
Session session = factory.getSession();
session.init(null);
try {
diff --git a/public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/drmaa/v1_0/LibDrmaaPipelineTest.java b/public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/drmaa/v1_0/LibDrmaaQueueTest.java
similarity index 97%
rename from public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/drmaa/v1_0/LibDrmaaPipelineTest.java
rename to public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/drmaa/v1_0/LibDrmaaQueueTest.java
index 13bad765b..3d861f078 100644
--- a/public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/drmaa/v1_0/LibDrmaaPipelineTest.java
+++ b/public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/drmaa/v1_0/LibDrmaaQueueTest.java
@@ -41,7 +41,7 @@ import java.io.File;
import java.util.Arrays;
import java.util.List;
-public class LibDrmaaPipelineTest extends BaseTest {
+public class LibDrmaaQueueTest extends BaseTest {
private String implementation = null;
@Test
@@ -88,7 +88,7 @@ public class LibDrmaaPipelineTest extends BaseTest {
@Test(dependsOnMethods = { "testDrmaa" })
public void testSubmitEcho() throws Exception {
- if ( ! pipelineTestRunModeIsSet ) {
+ if ( ! queueTestRunModeIsSet ) {
throw new SkipException("Skipping testSubmitEcho because we are in pipeline test dry run mode");
}
@@ -96,7 +96,7 @@ public class LibDrmaaPipelineTest extends BaseTest {
System.err.println(" *********************************************************");
System.err.println(" ***********************************************************");
System.err.println(" **** ****");
- System.err.println(" **** Skipping LibDrmaaPipelineTest.testSubmitEcho() ****");
+ System.err.println(" **** Skipping LibDrmaaQueueTest.testSubmitEcho() ****");
System.err.println(" **** Are you using the dotkit .combined_LSF_SGE? ****");
System.err.println(" **** ****");
System.err.println(" ***********************************************************");
@@ -107,7 +107,7 @@ public class LibDrmaaPipelineTest extends BaseTest {
Memory error = new Memory(LibDrmaa.DRMAA_ERROR_STRING_BUFFER);
int errnum;
- File outFile = tryCreateNetworkTempFile("LibDrmaaPipelineTest.out");
+ File outFile = tryCreateNetworkTempFile("LibDrmaaQueueTest.out");
errnum = LibDrmaa.drmaa_init(null, error, LibDrmaa.DRMAA_ERROR_STRING_BUFFER_LEN);
diff --git a/public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/lsf/v7_0_6/LibBatPipelineTest.java b/public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/lsf/v7_0_6/LibBatQueueTest.java
similarity index 92%
rename from public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/lsf/v7_0_6/LibBatPipelineTest.java
rename to public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/lsf/v7_0_6/LibBatQueueTest.java
index 4db600fc1..d7ac75695 100644
--- a/public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/lsf/v7_0_6/LibBatPipelineTest.java
+++ b/public/gatk-framework/src/test/java/org/broadinstitute/sting/jna/lsf/v7_0_6/LibBatQueueTest.java
@@ -39,12 +39,12 @@ import org.broadinstitute.sting.jna.lsf.v7_0_6.LibBat.*;
import java.io.File;
/**
- * Really unit tests, but these test will only run on systems with LSF setup.
+ * Really unit tests, but these tests will only run on systems with LSF set up.
*/
-public class LibBatPipelineTest extends BaseTest {
+public class LibBatQueueTest extends BaseTest {
@BeforeClass
public void initLibBat() {
- Assert.assertFalse(LibBat.lsb_init("LibBatPipelineTest") < 0, LibBat.lsb_sperror("lsb_init() failed"));
+ Assert.assertFalse(LibBat.lsb_init("LibBatQueueTest") < 0, LibBat.lsb_sperror("lsb_init() failed"));
}
@Test
@@ -94,19 +94,19 @@ public class LibBatPipelineTest extends BaseTest {
@Test
public void testSubmitEcho() throws Exception {
- if ( ! pipelineTestRunModeIsSet ) {
- throw new SkipException("Skipping testSubmitEcho because we are in pipeline test dry run mode");
+ if ( ! queueTestRunModeIsSet ) {
+ throw new SkipException("Skipping testSubmitEcho because we are in queue test dry run mode");
}
String queue = "hour";
- File outFile = tryCreateNetworkTempFile("LibBatPipelineTest.out");
+ File outFile = tryCreateNetworkTempFile("LibBatQueueTest.out");
submit req = new submit();
for (int i = 0; i < LibLsf.LSF_RLIM_NLIMITS; i++)
req.rLimits[i] = LibLsf.DEFAULT_RLIMIT;
- req.projectName = "LibBatPipelineTest";
+ req.projectName = "LibBatQueueTest";
req.options |= LibBat.SUB_PROJECT_NAME;
req.queue = queue;
diff --git a/public/gatk-package/pom.xml b/public/gatk-package/pom.xml
index 6a8ce94af..606d9f030 100644
--- a/public/gatk-package/pom.xml
+++ b/public/gatk-package/pom.xml
@@ -105,9 +105,9 @@
- pipeline-tests
+ queue-tests
- ${sting.serialpipelinetests.skipped}
+ ${sting.serialqueuetests.skipped}
org.broadinstitute.sting:.*
diff --git a/public/package-tests/pom.xml b/public/package-tests/pom.xml
index 38ef796ae..f53e7e02e 100644
--- a/public/package-tests/pom.xml
+++ b/public/package-tests/pom.xml
@@ -21,7 +21,7 @@
${project.basedir}/../..
true
true
- true
+ true
true
true
@@ -161,13 +161,13 @@
- pipeline-tests
+ queue-tests
verify
-
+
- ${sting.packagepipelinetests.skipped}
+ ${sting.packagequeuetests.skipped}
diff --git a/public/pom.xml b/public/pom.xml
index 0cf40a052..9a0a8b2d0 100644
--- a/public/pom.xml
+++ b/public/pom.xml
@@ -19,7 +19,7 @@
sting-utils
gatk-framework
gatk-package
-
+
diff --git a/public/queue-framework/pom.xml b/public/queue-framework/pom.xml
index 40c1ad5f0..ece0478b7 100644
--- a/public/queue-framework/pom.xml
+++ b/public/queue-framework/pom.xml
@@ -198,7 +198,7 @@
package-knowledgebasetests
- package-pipelinetests
+ package-queuetests
diff --git a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/PipelineTestEvalSpec.scala b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/QueueTestEvalSpec.scala
similarity index 98%
rename from public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/PipelineTestEvalSpec.scala
rename to public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/QueueTestEvalSpec.scala
index 4beb81c93..2295d7185 100644
--- a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/PipelineTestEvalSpec.scala
+++ b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/QueueTestEvalSpec.scala
@@ -28,7 +28,7 @@ package org.broadinstitute.sting.queue.pipeline
/**
* Data validations to evaluate on a GATKReport.
*/
-class PipelineTestEvalSpec {
+class QueueTestEvalSpec {
/** Eval modules to output. */
var evalReport: String = _
diff --git a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/PipelineTestSpec.scala b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/QueueTestSpec.scala
similarity index 96%
rename from public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/PipelineTestSpec.scala
rename to public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/QueueTestSpec.scala
index 3dc761382..e05350bce 100644
--- a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/PipelineTestSpec.scala
+++ b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/QueueTestSpec.scala
@@ -25,7 +25,7 @@
package org.broadinstitute.sting.queue.pipeline
-class PipelineTestSpec(var name: String = null) {
+class QueueTestSpec(var name: String = null) {
/** The arguments to pass to the Queue test, ex: "-S scala/qscript/examples/HelloWorld.scala" */
var args: String = _
@@ -40,7 +40,7 @@ class PipelineTestSpec(var name: String = null) {
var fileMD5s = Map.empty[String, String]
/** VariantEval validations to run on a VCF after the pipeline has completed. */
- var evalSpec: PipelineTestEvalSpec = _
+ var evalSpec: QueueTestEvalSpec = _
/** Expected exception from the test. */
var expectedException: Class[_ <: Exception] = null
diff --git a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleCountLociPipelineTest.scala b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleCountLociQueueTest.scala
similarity index 90%
rename from public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleCountLociPipelineTest.scala
rename to public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleCountLociQueueTest.scala
index 291894244..b1149054a 100644
--- a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleCountLociPipelineTest.scala
+++ b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleCountLociQueueTest.scala
@@ -26,14 +26,14 @@
package org.broadinstitute.sting.queue.pipeline.examples
import org.testng.annotations.Test
-import org.broadinstitute.sting.queue.pipeline.{PipelineTest, PipelineTestSpec}
+import org.broadinstitute.sting.queue.pipeline.{QueueTest, QueueTestSpec}
import org.broadinstitute.sting.BaseTest
-class ExampleCountLociPipelineTest {
+class ExampleCountLociQueueTest {
@Test(timeOut=36000000)
def testCountLoci() {
val testOut = "count.out"
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "countloci"
spec.args = Array(
" -S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/ExampleCountLoci.scala",
@@ -41,6 +41,6 @@ class ExampleCountLociPipelineTest {
" -I " + BaseTest.publicTestDir + "exampleBAM.bam",
" -o " + testOut).mkString
spec.fileMD5s += testOut -> "ade93df31a6150321c1067e749cae9be"
- PipelineTest.executeTest(spec)
+ QueueTest.executeTest(spec)
}
}
\ No newline at end of file
diff --git a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleCountReadsPipelineTest.scala b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleCountReadsQueueTest.scala
similarity index 89%
rename from public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleCountReadsPipelineTest.scala
rename to public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleCountReadsQueueTest.scala
index 2ec84e85f..e023a9dda 100644
--- a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleCountReadsPipelineTest.scala
+++ b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleCountReadsQueueTest.scala
@@ -26,18 +26,18 @@
package org.broadinstitute.sting.queue.pipeline.examples
import org.testng.annotations.Test
-import org.broadinstitute.sting.queue.pipeline.{PipelineTest, PipelineTestSpec}
+import org.broadinstitute.sting.queue.pipeline.{QueueTest, QueueTestSpec}
import org.broadinstitute.sting.BaseTest
-class ExampleCountReadsPipelineTest {
+class ExampleCountReadsQueueTest {
@Test(timeOut=36000000)
def testCountReads() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "countreads"
spec.args = Array(
" -S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/ExampleCountReads.scala",
" -R " + BaseTest.publicTestDir + "exampleFASTA.fasta",
" -I " + BaseTest.publicTestDir + "exampleBAM.bam").mkString
- PipelineTest.executeTest(spec)
+ QueueTest.executeTest(spec)
}
}
diff --git a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExamplePrintReadsPipelineTest.scala b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExamplePrintReadsQueueTest.scala
similarity index 90%
rename from public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExamplePrintReadsPipelineTest.scala
rename to public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExamplePrintReadsQueueTest.scala
index b9964d187..667187bd2 100644
--- a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExamplePrintReadsPipelineTest.scala
+++ b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExamplePrintReadsQueueTest.scala
@@ -50,34 +50,34 @@ package org.broadinstitute.sting.queue.pipeline.examples
*/
import org.testng.annotations.Test
-import org.broadinstitute.sting.queue.pipeline.{PipelineTest, PipelineTestSpec}
+import org.broadinstitute.sting.queue.pipeline.{QueueTest, QueueTestSpec}
import org.broadinstitute.sting.BaseTest
-class ExamplePrintReadsPipelineTest {
+class ExamplePrintReadsQueueTest {
@Test(timeOut=36000000)
def testDevNullOutput() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "devnulloutput"
spec.args = Array(
" -S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/ExamplePrintReads.scala",
" -R " + BaseTest.publicTestDir + "exampleFASTA.fasta",
" -I " + BaseTest.publicTestDir + "exampleBAM.bam",
" -out /dev/null").mkString
- spec.jobRunners = PipelineTest.allJobRunners
- PipelineTest.executeTest(spec)
+ spec.jobRunners = QueueTest.allJobRunners
+ QueueTest.executeTest(spec)
}
@Test(timeOut=36000000)
def testCleanupBai() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "cleanupbai"
spec.args = Array(
" -S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/ExamplePrintReads.scala",
" -R " + BaseTest.publicTestDir + "exampleFASTA.fasta",
" -I " + BaseTest.publicTestDir + "exampleBAM.bam",
" -out exampleOut.bam").mkString
- spec.jobRunners = PipelineTest.allJobRunners
+ spec.jobRunners = QueueTest.allJobRunners
spec.unexpectedFilePaths :+= ".queue/scatterGather/ExamplePrintReads-1-sg/temp_1_of_1/exampleOut.bai"
- PipelineTest.executeTest(spec)
+ QueueTest.executeTest(spec)
}
}
diff --git a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleReadFilterPipelineTest.scala b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleReadFilterQueueTest.scala
similarity index 95%
rename from public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleReadFilterPipelineTest.scala
rename to public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleReadFilterQueueTest.scala
index 7d74e1a5c..82fd57ee3 100644
--- a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleReadFilterPipelineTest.scala
+++ b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleReadFilterQueueTest.scala
@@ -74,18 +74,18 @@ package org.broadinstitute.sting.queue.pipeline.examples
*/
import org.testng.annotations.Test
-import org.broadinstitute.sting.queue.pipeline.{PipelineTest, PipelineTestSpec}
+import org.broadinstitute.sting.queue.pipeline.{QueueTest, QueueTestSpec}
import org.broadinstitute.sting.BaseTest
-class ExampleReadFilterPipelineTest {
+class ExampleReadFilterQueueTest {
@Test(timeOut=36000000)
def testExampleReadFilter() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "examplereadfilter"
spec.args = Array(
" -S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/ExampleReadFilter.scala",
" -R " + BaseTest.publicTestDir + "exampleFASTA.fasta",
" -I " + BaseTest.publicTestDir + "exampleBAM.bam").mkString
- PipelineTest.executeTest(spec)
+ QueueTest.executeTest(spec)
}
}
diff --git a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleRetryMemoryLimitPipelineTest.scala b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleRetryMemoryLimitQueueTest.scala
similarity index 87%
rename from public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleRetryMemoryLimitPipelineTest.scala
rename to public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleRetryMemoryLimitQueueTest.scala
index e98ca6756..3e314708c 100644
--- a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleRetryMemoryLimitPipelineTest.scala
+++ b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleRetryMemoryLimitQueueTest.scala
@@ -26,22 +26,22 @@
package org.broadinstitute.sting.queue.pipeline.examples
import org.testng.annotations.Test
-import org.broadinstitute.sting.queue.pipeline.{PipelineTest, PipelineTestSpec}
+import org.broadinstitute.sting.queue.pipeline.{QueueTest, QueueTestSpec}
import org.broadinstitute.sting.BaseTest
-class ExampleRetryMemoryLimitPipelineTest {
+class ExampleRetryMemoryLimitQueueTest {
// This test is currently disabled due to unexplained intermittent failures (see GSA-943)
@Test(timeOut=36000000,enabled = false)
def testRetryMemoryLimit() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "RetryMemoryLimit"
spec.args = Array(
" -S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/ExampleRetryMemoryLimit.scala",
" -R " + BaseTest.publicTestDir + "exampleFASTA.fasta",
" -I " + BaseTest.publicTestDir + "exampleBAM.bam",
" -retry 1").mkString
- spec.jobRunners = PipelineTest.allJobRunners
- PipelineTest.executeTest(spec)
+ spec.jobRunners = QueueTest.allJobRunners
+ QueueTest.executeTest(spec)
}
}
diff --git a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleUnifiedGenotyperPipelineTest.scala b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleUnifiedGenotyperQueueTest.scala
similarity index 87%
rename from public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleUnifiedGenotyperPipelineTest.scala
rename to public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleUnifiedGenotyperQueueTest.scala
index b054164a1..20f97ea61 100644
--- a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleUnifiedGenotyperPipelineTest.scala
+++ b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/ExampleUnifiedGenotyperQueueTest.scala
@@ -26,13 +26,13 @@
package org.broadinstitute.sting.queue.pipeline.examples
import org.testng.annotations.{DataProvider, Test}
-import org.broadinstitute.sting.queue.pipeline.{PipelineTest, PipelineTestSpec}
+import org.broadinstitute.sting.queue.pipeline.{QueueTest, QueueTestSpec}
import org.broadinstitute.sting.BaseTest
-class ExampleUnifiedGenotyperPipelineTest {
+class ExampleUnifiedGenotyperQueueTest {
@Test(timeOut=36000000)
def testUnifiedGenotyper() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "unifiedgenotyper"
spec.args = Array(
" -S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/ExampleUnifiedGenotyper.scala",
@@ -40,8 +40,8 @@ class ExampleUnifiedGenotyperPipelineTest {
" -I " + BaseTest.publicTestDir + "exampleBAM.bam",
" -filter QD",
" -filterExpression 'QD < 2.0'").mkString
- spec.jobRunners = PipelineTest.allJobRunners
- PipelineTest.executeTest(spec)
+ spec.jobRunners = QueueTest.allJobRunners
+ QueueTest.executeTest(spec)
}
@DataProvider(name = "ugIntervals")
@@ -54,7 +54,7 @@ class ExampleUnifiedGenotyperPipelineTest {
@Test(dataProvider = "ugIntervals", timeOut=36000000)
def testUnifiedGenotyperWithIntervals(intervalsName: String, intervalsPath: String) {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "unifiedgenotyper_with_" + intervalsName
spec.args = Array(
" -S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/ExampleUnifiedGenotyper.scala",
@@ -62,20 +62,20 @@ class ExampleUnifiedGenotyperPipelineTest {
" -R " + BaseTest.hg18Reference,
" -L " + intervalsPath).mkString
spec.jobRunners = Seq("Lsf706")
- PipelineTest.executeTest(spec)
+ QueueTest.executeTest(spec)
}
@Test(timeOut=36000000)
def testUnifiedGenotyperNoGCOpt() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "unifiedgenotyper_no_gc_opt"
spec.args = Array(
" -S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/ExampleUnifiedGenotyper.scala",
" -R " + BaseTest.publicTestDir + "exampleFASTA.fasta",
" -I " + BaseTest.publicTestDir + "exampleBAM.bam",
" -noGCOpt").mkString
- spec.jobRunners = PipelineTest.allJobRunners
- PipelineTest.executeTest(spec)
+ spec.jobRunners = QueueTest.allJobRunners
+ QueueTest.executeTest(spec)
}
@DataProvider(name="resMemReqParams")
@@ -83,7 +83,7 @@ class ExampleUnifiedGenotyperPipelineTest {
@Test(dataProvider = "resMemReqParams", timeOut=36000000)
def testUnifiedGenotyperResMemReqParam(reqParam: String) {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "unifiedgenotyper_" + reqParam
spec.args = Array(
" -S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/ExampleUnifiedGenotyper.scala",
@@ -91,21 +91,21 @@ class ExampleUnifiedGenotyperPipelineTest {
" -I " + BaseTest.publicTestDir + "exampleBAM.bam",
" -resMemReqParam " + reqParam).mkString
spec.jobRunners = Seq("GridEngine")
- PipelineTest.executeTest(spec)
+ QueueTest.executeTest(spec)
}
@Test(timeOut=36000000)
def testUnifiedGenotyperLogDirectory() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "unifiedgenotyper_with_log_directory"
spec.args = Array(
" -S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/ExampleUnifiedGenotyper.scala",
" -R " + BaseTest.publicTestDir + "exampleFASTA.fasta",
" -I " + BaseTest.publicTestDir + "exampleBAM.bam",
" -logDir exampleUGLogDir").mkString
- spec.jobRunners = PipelineTest.allJobRunners
+ spec.jobRunners = QueueTest.allJobRunners
spec.expectedFilePaths :+= "exampleUGLogDir/exampleBAM.unfiltered.vcf.out"
spec.expectedFilePaths :+= "exampleUGLogDir/exampleBAM.unfiltered.eval.out"
- PipelineTest.executeTest(spec)
+ QueueTest.executeTest(spec)
}
}
diff --git a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/HelloWorldPipelineTest.scala b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/HelloWorldQueueTest.scala
similarity index 79%
rename from public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/HelloWorldPipelineTest.scala
rename to public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/HelloWorldQueueTest.scala
index 0f645cb2a..5d3923250 100644
--- a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/HelloWorldPipelineTest.scala
+++ b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/examples/HelloWorldQueueTest.scala
@@ -26,127 +26,127 @@
package org.broadinstitute.sting.queue.pipeline.examples
import org.testng.annotations.Test
-import org.broadinstitute.sting.queue.pipeline.{PipelineTest, PipelineTestSpec}
+import org.broadinstitute.sting.queue.pipeline.{QueueTest, QueueTestSpec}
-class HelloWorldPipelineTest {
+class HelloWorldQueueTest {
@Test(timeOut=36000000)
def testHelloWorld() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "HelloWorld"
spec.args = "-S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/HelloWorld.scala"
- spec.jobRunners = PipelineTest.allJobRunners
- PipelineTest.executeTest(spec)
+ spec.jobRunners = QueueTest.allJobRunners
+ QueueTest.executeTest(spec)
}
@Test(timeOut=36000000)
def testHelloWorldWithRunName() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "HelloWorldWithRunName"
spec.args = "-S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/HelloWorld.scala" +
" -runName HelloWorld"
- spec.jobRunners = PipelineTest.allJobRunners
- PipelineTest.executeTest(spec)
+ spec.jobRunners = QueueTest.allJobRunners
+ QueueTest.executeTest(spec)
}
@Test(timeOut=36000000)
def testHelloWorldWithMemoryLimit() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "HelloWorldMemoryLimit"
spec.args = "-S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/HelloWorld.scala" +
" -memLimit 1.25"
- spec.jobRunners = PipelineTest.allJobRunners
- PipelineTest.executeTest(spec)
+ spec.jobRunners = QueueTest.allJobRunners
+ QueueTest.executeTest(spec)
}
@Test(timeOut=36000000)
def testHelloWorldWithPriority() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "HelloWorldWithPriority"
spec.args = "-S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/HelloWorld.scala" +
" -jobPriority 100"
- spec.jobRunners = PipelineTest.allJobRunners
- PipelineTest.executeTest(spec)
+ spec.jobRunners = QueueTest.allJobRunners
+ QueueTest.executeTest(spec)
}
@Test(timeOut=36000000)
def testHelloWorldWithLsfResource() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "HelloWorldWithLsfResource"
spec.args = "-S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/HelloWorld.scala" +
" -jobResReq rusage[iodine_io=1] -jobResReq select[swp>0] -jobResReq order[swp]"
spec.jobRunners = Seq("Lsf706")
- PipelineTest.executeTest(spec)
+ QueueTest.executeTest(spec)
}
@Test(timeOut=36000000)
def testHelloWorldWithLsfResourceAndMemoryLimit() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "HelloWorldWithLsfResourceAndMemoryLimit"
spec.args = "-S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/HelloWorld.scala" +
" -memLimit 1.25 -jobResReq rusage[iodine_io=1] -jobResReq select[swp>0] -jobResReq order[swp]"
spec.jobRunners = Seq("Lsf706")
- PipelineTest.executeTest(spec)
+ QueueTest.executeTest(spec)
}
@Test(timeOut=36000000)
def testHelloWorldWithLsfEnvironment() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "HelloWorldWithLsfEnvironment"
spec.args = "-S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/HelloWorld.scala" +
" -jobEnv tv"
spec.jobRunners = Seq("Lsf706")
- PipelineTest.executeTest(spec)
+ QueueTest.executeTest(spec)
}
@Test(timeOut=36000000)
def testHelloWorldWithGridEngineResource() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "HelloWorldWithGridEngineResource"
spec.args = "-S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/HelloWorld.scala" +
" -jobResReq s_core=1000M"
spec.jobRunners = Seq("GridEngine")
- PipelineTest.executeTest(spec)
+ QueueTest.executeTest(spec)
}
@Test(timeOut=36000000)
def testHelloWorldWithGridEngineResourceAndMemoryLimit() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "HelloWorldWithGridEngineResourceAndMemoryLimit"
spec.args = "-S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/HelloWorld.scala" +
" -memLimit 1.25 -jobResReq s_core=1000M"
spec.jobRunners = Seq("GridEngine")
- PipelineTest.executeTest(spec)
+ QueueTest.executeTest(spec)
}
@Test(timeOut=36000000)
def testHelloWorldWithGridEngineEnvironment() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "HelloWorldWithGridEngineEnvironment"
spec.args = "-S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/HelloWorld.scala" +
" -jobEnv \"make 1\""
spec.jobRunners = Seq("GridEngine")
- PipelineTest.executeTest(spec)
+ QueueTest.executeTest(spec)
}
// disabled because our DRMAA implementation doesn't support wallTime
@Test(enabled=false, timeOut=36000000)
def testHelloWorldWithWalltime() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "HelloWorldWithWalltime"
spec.args = "-S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/HelloWorld.scala" +
" -wallTime 100"
- spec.jobRunners = PipelineTest.allJobRunners
- PipelineTest.executeTest(spec)
+ spec.jobRunners = QueueTest.allJobRunners
+ QueueTest.executeTest(spec)
}
@Test(timeOut=36000000)
def testHelloWorldWithLogDirectory() {
- val spec = new PipelineTestSpec
+ val spec = new QueueTestSpec
spec.name = "HelloWorldWithLogDirectory"
spec.args = "-S public/scala/qscript/org/broadinstitute/sting/queue/qscripts/examples/HelloWorld.scala" +
" -logDir pipelineLogDir"
- spec.jobRunners = PipelineTest.allJobRunners
+ spec.jobRunners = QueueTest.allJobRunners
spec.expectedFilePaths = Seq("pipelineLogDir/HelloWorld-1.out")
- PipelineTest.executeTest(spec)
+ QueueTest.executeTest(spec)
}
}
diff --git a/public/queue-package/pom.xml b/public/queue-package/pom.xml
index 4ff9a1381..89b547b2f 100644
--- a/public/queue-package/pom.xml
+++ b/public/queue-package/pom.xml
@@ -144,9 +144,9 @@
- pipeline-tests
+ queue-tests
- ${sting.serialpipelinetests.skipped}
+ ${sting.serialqueuetests.skipped}
org.broadinstitute.sting:.*
diff --git a/public/sting-root/pom.xml b/public/sting-root/pom.xml
index 44644e13d..5b3dfe43b 100644
--- a/public/sting-root/pom.xml
+++ b/public/sting-root/pom.xml
@@ -31,10 +31,10 @@
true
${sting.committests.skipped}
${sting.committests.skipped}
- ${sting.committests.skipped}
+ ${sting.committests.skipped}
true
true
- false
+ false
1g
4g
4
@@ -412,7 +412,7 @@
diff
true
- ${sting.pipelinetests.run}
+ ${sting.queuetests.run}
${java.io.tmpdir}
@@ -435,19 +435,19 @@
- pipeline-tests
+ queue-tests
integration-test
verify
-
+
-
- ${sting.pipelinetests.skipped}
- ${project.build.directory}/failsafe-reports/pipeline/${it.test}
- ${project.build.directory}/failsafe-reports/pipeline/failsafe-summary-${it.test}.xml
+
+ ${sting.queuetests.skipped}
+ ${project.build.directory}/failsafe-reports/queuetest/${it.test}
+ ${project.build.directory}/failsafe-reports/queuetest/failsafe-summary-${it.test}.xml
- **/*PipelineTest.class
+ **/*QueueTest.class
diff --git a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/PipelineTest.scala b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/QueueTest.scala
similarity index 85%
rename from public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/PipelineTest.scala
rename to public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/QueueTest.scala
index 2800ba2da..9c32a40be 100644
--- a/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/PipelineTest.scala
+++ b/public/queue-framework/src/test/scala/org/broadinstitute/sting/queue/pipeline/QueueTest.scala
@@ -39,13 +39,13 @@ import org.broadinstitute.sting.gatk.report.GATKReport
import org.apache.commons.io.FileUtils
import org.apache.commons.io.filefilter.WildcardFileFilter
-object PipelineTest extends BaseTest with Logging {
+object QueueTest extends BaseTest with Logging {
private val validationReportsDataLocation = "/humgen/gsa-hpprojects/GATK/validationreports/submitted/"
private val md5DB = new MD5DB()
/**
* All the job runners configured to run PipelineTests at The Broad.
*/
final val allJobRunners = Seq("Lsf706", "GridEngine", "Shell")
@@ -56,15 +56,15 @@ object PipelineTest extends BaseTest with Logging {
/**
* Returns the top level output path to this test.
- * @param testName The name of the test passed to PipelineTest.executeTest()
+ * @param testName The name of the test passed to QueueTest.executeTest()
* @param jobRunner The name of the job manager to run the jobs.
* @return the top level output path to this test.
*/
- def testDir(testName: String, jobRunner: String) = "pipelinetests/%s/%s/".format(testName, jobRunner)
+ def testDir(testName: String, jobRunner: String) = "queuetests/%s/%s/".format(testName, jobRunner)
/**
* Returns the directory where relative output files will be written for this test.
- * @param testName The name of the test passed to PipelineTest.executeTest()
+ * @param testName The name of the test passed to QueueTest.executeTest()
* @param jobRunner The name of the job manager to run the jobs.
* @return the directory where relative output files will be written for this test.
*/
@@ -72,44 +72,44 @@ object PipelineTest extends BaseTest with Logging {
/**
* Returns the directory where temp files will be written for this test.
- * @param testName The name of the test passed to PipelineTest.executeTest()
+ * @param testName The name of the test passed to QueueTest.executeTest()
* @param jobRunner The name of the job manager to run the jobs.
* @return the directory where temp files will be written for this test.
*/
private def tempDir(testName: String, jobRunner: String) = testDir(testName, jobRunner) + "temp/"
/**
* Runs the pipelineTest.
* @param pipelineTest test to run.
*/
- def executeTest(pipelineTest: PipelineTestSpec) {
- var jobRunners = pipelineTest.jobRunners
+ def executeTest(queueTest: QueueTestSpec) {
+ var jobRunners = queueTest.jobRunners
if (jobRunners == null)
jobRunners = defaultJobRunners
- jobRunners.foreach(executeTest(pipelineTest, _))
+ jobRunners.foreach(executeTest(queueTest, _))
}
/**
* Runs the pipelineTest.
* @param pipelineTest test to run.
* @param jobRunner The name of the job manager to run the jobs.
*/
- def executeTest(pipelineTest: PipelineTestSpec, jobRunner: String) {
+ def executeTest(queueTest: QueueTestSpec, jobRunner: String) {
// Reset the order of functions added to the graph.
QScript.resetAddOrder()
- val name = pipelineTest.name
+ val name = queueTest.name
if (name == null)
- Assert.fail("PipelineTestSpec.name is null")
+ Assert.fail("QueueTestSpec.name is null")
println(Utils.dupString('-', 80))
- executeTest(name, pipelineTest.args, pipelineTest.jobQueue, pipelineTest.expectedException, jobRunner)
- if (BaseTest.pipelineTestRunModeIsSet) {
- assertMatchingMD5s(name, pipelineTest.fileMD5s.map{case (file, md5) => new File(runDir(name, jobRunner), file) -> md5}, pipelineTest.parameterize)
- if (pipelineTest.evalSpec != null)
- validateEval(name, pipelineTest.evalSpec, jobRunner)
- for (path <- pipelineTest.expectedFilePaths)
+ executeTest(name, queueTest.args, queueTest.jobQueue, queueTest.expectedException, jobRunner)
+ if (BaseTest.queueTestRunModeIsSet) {
+ assertMatchingMD5s(name, queueTest.fileMD5s.map{case (file, md5) => new File(runDir(name, jobRunner), file) -> md5}, queueTest.parameterize)
+ if (queueTest.evalSpec != null)
+ validateEval(name, queueTest.evalSpec, jobRunner)
+ for (path <- queueTest.expectedFilePaths)
assertPathExists(runDir(name, jobRunner), path)
- for (path <- pipelineTest.unexpectedFilePaths)
+ for (path <- queueTest.unexpectedFilePaths)
assertPathDoesNotExist(runDir(name, jobRunner), path)
println(" => %s PASSED (%s)".format(name, jobRunner))
}
@@ -128,7 +128,7 @@ object PipelineTest extends BaseTest with Logging {
Assert.fail("%d of %d MD5s did not match".format(failed, fileMD5s.size))
}
- private def validateEval(name: String, evalSpec: PipelineTestEvalSpec, jobRunner: String) {
+ private def validateEval(name: String, evalSpec: QueueTestEvalSpec, jobRunner: String) {
// write the report to the shared validation data location
val formatter = new SimpleDateFormat("yyyy.MM.dd.HH.mm.ss")
val reportLocation = "%s%s/%s/validation.%s.eval".format(validationReportsDataLocation, jobRunner, name, formatter.format(new Date))
@@ -176,7 +176,7 @@ object PipelineTest extends BaseTest with Logging {
if (jobQueue != null)
command = Utils.appendArray(command, "-jobQueue", jobQueue)
- if (BaseTest.pipelineTestRunModeIsSet)
+ if (BaseTest.queueTestRunModeIsSet)
command = Utils.appendArray(command, "-run")
// run the executable
@@ -39,13 +39,13 @@ import org.broadinstitute.sting.gatk.report.GATKReport
private val md5DB = new MD5DB()
/**
- * All the job runners configured to run PipelineTests at The Broad.
+ * All the job runners configured to run QueueTests at The Broad.
*/
final val allJobRunners = Seq("Lsf706", "GridEngine", "Shell")
@@ -72,44 +72,44 @@ object PipelineTest extends BaseTest with Logging {
private def tempDir(testName: String, jobRunner: String) = testDir(testName, jobRunner) + "temp/"
/**
- * Runs the pipelineTest.
- * @param pipelineTest test to run.
+ * Runs the queueTest.
+ * @param queueTest test to run.
*/
@@ -72,44 +72,44 @@ object PipelineTest extends BaseTest with Logging {
}
/**
- * Runs the pipelineTest.
- * @param pipelineTest test to run.
+ * Runs the queueTest.
+ * @param queueTest test to run.
* @param jobRunner The name of the job manager to run the jobs.
*/